@@ -9,7 +9,7 @@ pub fn regex<T: AsRef<str> + InputType>(
     if let Ok(true) = Regex::new(regex).map(|re| re.is_match(value.as_ref())) {
         Ok(())
     } else {
-        Err("value is valid".into())
+        Err(format_args!("value doesn't match expected format '{}'", regex).into())
     }
 }
 
